@@ -1,33 +1,14 @@
-bprobgHs <- function(params, BivD, nC, nu, gev.eq1, gev.eq2, shape1, shape2, H.n, y1.y2, y1.cy2, cy1.y2, cy1.cy2, cy1, X1, X2, weights=weights, X1.d2, X2.d2, pPen1=NULL, pPen2=NULL, sp=NULL, qu.mag=NULL, gp1, gp2, fp, l.sp1, l.sp2, K=NULL, n=NULL, N=NULL, cuid=NULL, uidf=NULL, masses=NULL, NGQ=NULL, dat1all=NULL, dat2all=NULL, W=NULL){
+bprobgHs <- function(params, BivD, nC, nu, xi1, xi2, PL, eqPL, H.n, y1.y2, y1.cy2, cy1.y2, cy1.cy2, cy1, X1, X2, weights=weights, X1.d2, X2.d2, pPen1=NULL, pPen2=NULL, sp=NULL, qu.mag=NULL, gp1, gp2, fp, l.sp1, l.sp2, K=NULL, n=NULL, N=NULL, cuid=NULL, uidf=NULL, masses=NULL, NGQ=NULL, dat1all=NULL, dat2all=NULL, W=NULL,AT=FALSE){
 
   eta1 <- X1%*%params[1:X1.d2]
   eta2 <- X2%*%params[(X1.d2+1):(X1.d2+X2.d2)]
 
-
-  if(gev.eq1==FALSE && gev.eq2==TRUE) {p1 <- pnorm(eta1); d.n1 <- dnorm(eta1)
-                                       p2 <- 1-pgev(-eta2,shape=shape2); d.n2 <- dgev(-eta2,shape=shape2)}   
-
-  if(gev.eq1==TRUE && gev.eq2==FALSE) {p1 <- 1-pgev(-eta1,shape=shape1); d.n1 <- dgev(-eta1,shape=shape1)
-                                       p2 <- pnorm(eta2); d.n2 <- dnorm(eta2)}
-
-
-  if(gev.eq1==TRUE && gev.eq2==TRUE) {p1 <- 1-pgev(-eta1,shape=shape1); d.n1 <- dgev(-eta1,shape=shape1)
-                                      p2 <- 1-pgev(-eta2,shape=shape2); d.n2 <- dgev(-eta2,shape=shape2)}
-
-
-  if(gev.eq1==FALSE && gev.eq2==FALSE) { p1 <- pnorm(eta1); d.n1 <- dnorm(eta1)
-                                         p2 <- pnorm(eta2); d.n2 <- dnorm(eta2) } 
-
+  p1 <- pnorm(eta1); d.n1 <- dnorm(eta1)
+  p2 <- pnorm(eta2); d.n2 <- dnorm(eta2) 
 
   teta.st <- params[(X1.d2+X2.d2+1)]
   epsilon <- .Machine$double.eps*10^6
 
-
-  #p1 <- ifelse(p1 > 0.999999, 0.999999, p1)
-  #p1 <- ifelse(p1 < 0.000001, 0.000001, p1)
-  #p2 <- ifelse(p2 > 0.999999, 0.999999, p2)
-  #p2 <- ifelse(p2 < 0.000001, 0.000001, p2)
-
   criteria <- c(0,1)
   no.good <- apply(apply(cbind(p1,p2), c(1,2), `%in%`, criteria), 1, any)
   good <- no.good==FALSE
@@ -50,11 +31,11 @@ bprobgHs <- function(params, BivD, nC, nu, gev.eq1, gev.eq2, shape1, shape2, H.n
 
     if(BivD %in% c("N","T")      ){teta <- tanh(teta.st); if(teta %in% c(-1,1)) teta <- sign(teta)*0.9999999}
     if(BivD=="F")                  teta <- teta.st + epsilon
-    if(BivD %in% c("C0", "C180") ) teta <- exp(teta.st) + epsilon
+    if(BivD %in% c("C0", "C180") ) teta <-    exp(teta.st) + epsilon
     if(BivD %in% c("C90","C270") ) teta <- -( exp(teta.st) + epsilon ) 
-    if(BivD %in% c("J0", "J180") ) teta <- exp(teta.st) + 1 + epsilon 
+    if(BivD %in% c("J0", "J180") ) teta <-    exp(teta.st) + 1 + epsilon 
     if(BivD %in% c("J90","J270") ) teta <- -( exp(teta.st) + 1 + epsilon ) 
-    if(BivD %in% c("G0", "G180") ) teta <- exp(teta.st) + 1 
+    if(BivD %in% c("G0", "G180") ) teta <-    exp(teta.st) + 1 
     if(BivD %in% c("G90","G270") ) teta <- -( exp(teta.st) + 1 ) 
 
 if(BivD=="N") C.copula <- pmax( abs(pbinorm( qnorm(p1), qnorm(p2), cov12=teta)), 1000*.Machine$double.eps ) else C.copula <- BiCopCDF(p1,p2, nC, par=teta, par2=nu)
@@ -66,11 +47,9 @@ if(BivD=="N") C.copula <- pmax( abs(pbinorm( qnorm(p1), qnorm(p2), cov12=teta)),
   p01 <- pmax( p2 - p11, 1000*.Machine$double.eps )
   p00 <- pmax( 1- p11 - p10 - p01, 1000*.Machine$double.eps )
 
-
   l.par <- weights*( y1.y2*log(p11)+y1.cy2*log(p10)+cy1.y2*log(p01)+cy1.cy2*log(p00) )
 
-
-if(BivD=="N" && H.n==FALSE && gev.eq1==FALSE && gev.eq2==FALSE){
+if(BivD=="N" && H.n==FALSE){
 
   d.r <- 1/sqrt( pmax(10000*.Machine$double.eps, 1-teta^2) )
   A   <- pnorm( (eta2-teta*eta1)*d.r ); A.c <- 1 - A
@@ -93,19 +72,28 @@ if(BivD=="N" && H.n==FALSE && gev.eq1==FALSE && gev.eq2==FALSE){
 }else{
 
 
-dH <- copgHs(p1,p2,teta,teta.st,BivD,nC,nu)
-
+dH <- copgHs(p1,p2,eta1=NULL,eta2=NULL,teta,teta.st,xi1=NULL,xi1.st=NULL,xi2=NULL,xi2.st=NULL,BivD,nC,nu,PL,eqPL)
 
 c.copula.be1   <- dH$c.copula.be1
 c.copula.be2   <- dH$c.copula.be2
 c.copula.theta <- dH$c.copula.theta 
-            
+        
+if(AT==TRUE){
+
+    if(BivD %in% c("N","T")      ) add.b <- 1/cosh(teta.st)^2
+    if(BivD=="F")                  add.b <- 1
+    if(BivD %in% c("C0", "C180","J0", "J180","G0", "G180") ) add.b <-  exp(teta.st)
+    if(BivD %in% c("C90","C270","J90","J270","G90","G270") ) add.b <- -exp(teta.st)
+
+c.copula.theta <- c.copula.theta/add.b
+
+
+}
+  
 c.copula2.be1 <- dH$c.copula2.be1   
 c.copula2.be2 <- dH$c.copula2.be2 
 
 
-if(gev.eq1==FALSE && gev.eq2==FALSE){
-
 bit1.b1b1 <- c.copula2.be1*(d.n1)^2-c.copula.be1*d.n1*eta1
 bit2.b1b1 <- -d.n1*eta1-bit1.b1b1
 bit3.b1b1 <- -bit1.b1b1
@@ -116,79 +104,6 @@ bit2.b2b2 <- -bit1.b2b2
 bit3.b2b2 <- -d.n2*eta2-bit1.b2b2
 bit4.b2b2 <- -bit3.b2b2
 
-}
-
-if(gev.eq1==FALSE && gev.eq2==TRUE){
-
-bit1.b1b1 <- c.copula2.be1*(d.n1)^2-c.copula.be1*d.n1*eta1
-bit2.b1b1 <- -d.n1*eta1-bit1.b1b1
-bit3.b1b1 <- -bit1.b1b1
-bit4.b1b1 <- -bit2.b1b1
-
-d1_d.n2 <- (1 + shape2 * (-eta2))^(-1/shape2 - 1) * (exp(-(1 + shape2 * (-eta2))^(-1/shape2)) * 
-    ((1 + shape2 * (-eta2))^((-1/shape2) - 1) * ((-1/shape2) * shape2))) - (1 + 
-    shape2 * (-eta2))^((-1/shape2 - 1) - 1) * ((-1/shape2 - 1) * shape2) * exp(-(1 + 
-    shape2 * (-eta2))^(-1/shape2))
-
-
-
-bit1.b2b2 <- c.copula2.be2*(d.n2)^2+c.copula.be2*d1_d.n2
-bit2.b2b2 <- -bit1.b2b2
-bit3.b2b2 <- d1_d.n2-bit1.b2b2
-bit4.b2b2 <- -bit3.b2b2
-
-
-}
-
-
-if(gev.eq1==TRUE && gev.eq2==FALSE){
-
-
-d1_d.n1 <- (1 + shape1 * (-eta1))^(-1/shape1 - 1) * (exp(-(1 + shape1 * (-eta1))^(-1/shape1)) * 
-    ((1 + shape1 * (-eta1))^((-1/shape1) - 1) * ((-1/shape1) * shape1))) - (1 + 
-    shape1 * (-eta1))^((-1/shape1 - 1) - 1) * ((-1/shape1 - 1) * shape1) * exp(-(1 + 
-    shape1 * (-eta1))^(-1/shape1))
-
-
-bit1.b1b1 <- c.copula2.be1*(d.n1)^2+c.copula.be1*d1_d.n1 
-bit2.b1b1 <- d1_d.n1-bit1.b1b1 
-bit3.b1b1 <- -bit1.b1b1
-bit4.b1b1 <- -bit2.b1b1
-
-
-bit1.b2b2 <- c.copula2.be2*(d.n2)^2-c.copula.be2*d.n2*eta2 
-bit2.b2b2 <- -bit1.b2b2 
-bit3.b2b2 <- -d.n2*eta2-bit1.b2b2
-bit4.b2b2 <- -bit3.b2b2
-
-
-}
-
-if(gev.eq1==TRUE && gev.eq2==TRUE){
-
-d1_d.n1 <- (1 + shape1 * (-eta1))^(-1/shape1 - 1) * (exp(-(1 + shape1 * (-eta1))^(-1/shape1)) * 
-    ((1 + shape1 * (-eta1))^((-1/shape1) - 1) * ((-1/shape1) * shape1))) - (1 + 
-    shape1 * (-eta1))^((-1/shape1 - 1) - 1) * ((-1/shape1 - 1) * shape1) * exp(-(1 + 
-    shape1 * (-eta1))^(-1/shape1))
-
-bit1.b1b1 <- c.copula2.be1*(d.n1)^2+c.copula.be1*d1_d.n1 
-bit2.b1b1 <- d1_d.n1-bit1.b1b1 
-bit3.b1b1 <- -bit1.b1b1
-bit4.b1b1 <- -bit2.b1b1
-
-d1_d.n2 <- (1 + shape2 * (-eta2))^(-1/shape2 - 1) * (exp(-(1 + shape2 * (-eta2))^(-1/shape2)) * 
-    ((1 + shape2 * (-eta2))^((-1/shape2) - 1) * ((-1/shape2) * shape2))) - (1 + 
-    shape2 * (-eta2))^((-1/shape2 - 1) - 1) * ((-1/shape2 - 1) * shape2) * exp(-(1 + 
-    shape2 * (-eta2))^(-1/shape2))
-
-bit1.b2b2 <- c.copula2.be2*(d.n2)^2+c.copula.be2*d1_d.n2
-bit2.b2b2 <- -bit1.b2b2
-bit3.b2b2 <- d1_d.n2-bit1.b2b2
-bit4.b2b2 <- -bit3.b2b2
-
-}
-
-
 c.copula2.be1be2 <- dH$c.copula2.be1be2
 bit1.b1b2 <- c.copula2.be1be2 * d.n1 *d.n2
 bit2.b1b2 <- -bit1.b1b2
@@ -275,11 +190,18 @@ bit4.th2 <- bit1.th2
             ) 
 
          res <- -sum(l.par)
-         G   <- c( -colSums( c(dl.dbe1)*X1 ),
-                   -colSums( c(dl.dbe2)*X2 ),
-                   -sum( dl.drho )  )
+         G   <- -c( colSums( c(dl.dbe1)*X1 ),
+                    colSums( c(dl.dbe2)*X2 ),
+                    sum( dl.drho )  )
 
 
+if(AT==TRUE){
+
+         grad <- cbind( c(dl.dbe1)*X1 , c(dl.dbe2)*X2, dl.drho )   
+         H    <- crossprod(grad)
+
+            }
+
 
 if( ( l.sp1==0 && l.sp2==0 ) || fp==TRUE) S.h <- S.h1 <- S.h2 <- 0
 
@@ -300,7 +222,7 @@ if( ( l.sp1==0 && l.sp2==0 ) || fp==TRUE) S.h <- S.h1 <- S.h2 <- 0
     if(length(pPen2)!=0){ 
                           indP2 <- (qu.mag$off[l.sp1+1]-X1.d2):(-X1.d2+qu.mag$off[l.sp1+1]+qu.mag$rank[l.sp1+1]-1)
                           dimP2 <- length(indP2)
-                          ma2[indP2,indP2] <- S[indP2+X1.d2,indP2+X1.d2]
+                          ma2[indP2,indP2] <- S[(dimP1+1):(length(indP2)+dimP1),(dimP1+1):(length(indP2)+dimP1)]
                                 }                                 
     
     lP1 <- length(pPen1); lP2 <- length(pPen2) 
@@ -333,7 +255,7 @@ if( ( l.sp1==0 && l.sp2==0 ) || fp==TRUE) S.h <- S.h1 <- S.h2 <- 0
               dl.dbe1=dl.dbe1, dl.dbe2=dl.dbe2, dl.drho=dl.drho,
               d2l.be1.be1=d2l.be1.be1, d2l.be2.be2=d2l.be2.be2, 
               d2l.be1.be2=d2l.be1.be2, d2l.be1.rho=d2l.be1.rho,
-              d2l.be2.rho=d2l.be2.rho, d2l.rho.rho=d2l.rho.rho,good=good)      
+              d2l.be2.rho=d2l.be2.rho, d2l.rho.rho=d2l.rho.rho,good=good, PL=PL, eqPL=eqPL,BivD=BivD)      
 
 }
 
