@@ -1,22 +1,10 @@
-bprobgHsSS <- function(params, BivD, nC, nu, gev.eq1, gev.eq2, shape1, shape2, H.n, y1.y2, y1.cy2, cy1.y2, cy1.cy2, cy1, X1, X2, weights=weights, X1.d2, X2.d2, pPen1=NULL, pPen2=NULL, sp=NULL, qu.mag=NULL, gp1, gp2, fp, l.sp1, l.sp2, K=NULL, n=NULL, N=NULL, cuid=NULL, uidf=NULL, masses=NULL, NGQ=NULL, dat1all=NULL, dat2all=NULL, W=NULL){
+bprobgHsSS <- function(params, BivD, nC, nu, xi1, xi2, PL, eqPL, H.n, y1.y2, y1.cy2, cy1.y2, cy1.cy2, cy1, X1, X2, weights=weights, X1.d2, X2.d2, pPen1=NULL, pPen2=NULL, sp=NULL, qu.mag=NULL, gp1, gp2, fp, l.sp1, l.sp2, K=NULL, n=NULL, N=NULL, cuid=NULL, uidf=NULL, masses=NULL, NGQ=NULL, dat1all=NULL, dat2all=NULL, W=NULL){
 
   eta1 <- X1%*%params[1:X1.d2]
   eta2 <- X2%*%params[(X1.d2+1):(X1.d2+X2.d2)]
 
-
-  if(gev.eq1==FALSE && gev.eq2==TRUE) {p1 <- pnorm(eta1); d.n1 <- dnorm(eta1)
-                                       p2 <- 1-pgev(-eta2,shape=shape2); d.n2 <- dgev(-eta2,shape=shape2)}   
-
-  if(gev.eq1==TRUE && gev.eq2==FALSE) {p1 <- 1-pgev(-eta1,shape=shape1); d.n1 <- dgev(-eta1,shape=shape1)
-                                       p2 <- pnorm(eta2); d.n2 <- dnorm(eta2)}
-
-
-  if(gev.eq1==TRUE && gev.eq2==TRUE) {p1 <- 1-pgev(-eta1,shape=shape1); d.n1 <- dgev(-eta1,shape=shape1)
-                                      p2 <- 1-pgev(-eta2,shape=shape2); d.n2 <- dgev(-eta2,shape=shape2)}
-
-
-  if(gev.eq1==FALSE && gev.eq2==FALSE) { p1 <- pnorm(eta1); d.n1 <- dnorm(eta1)
-                                         p2 <- pnorm(eta2); d.n2 <- dnorm(eta2) } 
+  p1 <- pnorm(eta1); d.n1 <- dnorm(eta1)
+  p2 <- pnorm(eta2); d.n2 <- dnorm(eta2)  
 
   teta.st <- params[(X1.d2+X2.d2+1)]
   epsilon <- .Machine$double.eps*10^6
@@ -59,7 +47,7 @@ if(BivD=="N") C.copula <- pmax( abs(pbinorm( qnorm(p1), qnorm(p2), cov12=teta)),
 
   l.par <- weights*( y1.y2*log(p11) + y1.cy2*log(p10) + cy1*log(p0) ) 
 
-if(BivD=="N" && H.n==FALSE && gev.eq1==FALSE && gev.eq2==FALSE){
+if(BivD=="N" && H.n==FALSE){
 
   d.r  <- 1/sqrt( pmax(10000*.Machine$double.eps, 1-teta^2) )
   A   <- pnorm( (eta2-teta*eta1)*d.r ); A.c <- 1 - A
@@ -83,7 +71,7 @@ if(BivD=="N" && H.n==FALSE && gev.eq1==FALSE && gev.eq2==FALSE){
 }else{
 
 
-dH <- copgHs(p1,p2,teta,teta.st,BivD,nC,nu)
+dH <- copgHs(p1,p2,eta1=NULL,eta2=NULL,teta,teta.st,xi1=NULL,xi1.st=NULL,xi2=NULL,xi2.st=NULL,BivD,nC,nu,PL,eqPL)
 
 c.copula.be1   <- dH$c.copula.be1
 c.copula.be2   <- dH$c.copula.be2
@@ -92,9 +80,6 @@ c.copula.theta <- dH$c.copula.theta
 c.copula2.be1 <- dH$c.copula2.be1  
 c.copula2.be2 <- dH$c.copula2.be2 
 
-
-if(gev.eq1==FALSE && gev.eq2==FALSE){
-
 bit1.b1b1 <- c.copula2.be1*(d.n1)^2-c.copula.be1*d.n1*eta1
 bit2.b1b1 <- -d.n1*eta1-bit1.b1b1
 bit3.b1b1 <- d.n1*(eta1*p0-d.n1)/p0^2
@@ -102,69 +87,6 @@ bit3.b1b1 <- d.n1*(eta1*p0-d.n1)/p0^2
 bit1.b2b2 <- c.copula2.be2*(d.n2)^2-c.copula.be2*d.n2*eta2
 bit2.b2b2 <- -bit1.b2b2
 
-}
-
-if(gev.eq1==FALSE && gev.eq2==TRUE){
-
-bit1.b1b1 <- c.copula2.be1*(d.n1)^2-c.copula.be1*d.n1*eta1
-bit2.b1b1 <- -d.n1*eta1-bit1.b1b1
-bit3.b1b1 <- d.n1*(eta1*p0-d.n1)/p0^2
-
-d1_d.n2 <- (1 + shape2 * (-eta2))^(-1/shape2 - 1) * (exp(-(1 + shape2 * (-eta2))^(-1/shape2)) * 
-    ((1 + shape2 * (-eta2))^((-1/shape2) - 1) * ((-1/shape2) * shape2))) - (1 + 
-    shape2 * (-eta2))^((-1/shape2 - 1) - 1) * ((-1/shape2 - 1) * shape2) * exp(-(1 + 
-    shape2 * (-eta2))^(-1/shape2))
-
-
-bit1.b2b2 <- c.copula2.be2*(d.n2)^2+c.copula.be2*d1_d.n2
-bit2.b2b2 <- -bit1.b2b2
-
-
-}
-
-
-if(gev.eq1==TRUE && gev.eq2==FALSE){
-
-
-d1_d.n1 <- (1 + shape1 * (-eta1))^(-1/shape1 - 1) * (exp(-(1 + shape1 * (-eta1))^(-1/shape1)) * 
-    ((1 + shape1 * (-eta1))^((-1/shape1) - 1) * ((-1/shape1) * shape1))) - (1 + 
-    shape1 * (-eta1))^((-1/shape1 - 1) - 1) * ((-1/shape1 - 1) * shape1) * exp(-(1 + 
-    shape1 * (-eta1))^(-1/shape1))
-
-bit1.b1b1 <- c.copula2.be1*(d.n1)^2+c.copula.be1*d1_d.n1 
-bit2.b1b1 <- d1_d.n1-bit1.b1b1 
-bit3.b1b1 <- (-p0*d1_d.n1-d.n1^2)/p0^2 
-
-
-bit1.b2b2 <- c.copula2.be2*(d.n2)^2-c.copula.be2*d.n2*eta2
-bit2.b2b2 <- -bit1.b2b2
-
-
-}
-
-if(gev.eq1==TRUE && gev.eq2==TRUE){
-
-d1_d.n1 <- (1 + shape1 * (-eta1))^(-1/shape1 - 1) * (exp(-(1 + shape1 * (-eta1))^(-1/shape1)) * 
-    ((1 + shape1 * (-eta1))^((-1/shape1) - 1) * ((-1/shape1) * shape1))) - (1 + 
-    shape1 * (-eta1))^((-1/shape1 - 1) - 1) * ((-1/shape1 - 1) * shape1) * exp(-(1 + 
-    shape1 * (-eta1))^(-1/shape1))
-
-bit1.b1b1 <- c.copula2.be1*(d.n1)^2+c.copula.be1*d1_d.n1 
-bit2.b1b1 <- d1_d.n1-bit1.b1b1 
-bit3.b1b1 <- (-p0*d1_d.n1-d.n1^2)/p0^2 
-
-
-d1_d.n2 <- (1 + shape2 * (-eta2))^(-1/shape2 - 1) * (exp(-(1 + shape2 * (-eta2))^(-1/shape2)) * 
-    ((1 + shape2 * (-eta2))^((-1/shape2) - 1) * ((-1/shape2) * shape2))) - (1 + 
-    shape2 * (-eta2))^((-1/shape2 - 1) - 1) * ((-1/shape2 - 1) * shape2) * exp(-(1 + 
-    shape2 * (-eta2))^(-1/shape2))
-
-
-bit1.b2b2 <- c.copula2.be2*(d.n2)^2+c.copula.be2*d1_d.n2
-bit2.b2b2 <- -bit1.b2b2
-
-}
-
 
 c.copula2.be1be2 <- dH$c.copula2.be1be2
 bit1.b1b2 <- c.copula2.be1be2 * d.n1 *d.n2
@@ -227,9 +149,9 @@ bit2.th2 <- -bit1.th2
             ) 
 
          res <- -sum(l.par)
-         G   <- c( -colSums( c(dl.dbe1)*X1 ),
-                   -colSums( c(dl.dbe2)*X2 ),
-                   -sum( dl.drho )  )
+         G   <- -c( colSums( c(dl.dbe1)*X1 ),
+                    colSums( c(dl.dbe2)*X2 ),
+                    sum( dl.drho )  )
 
 
 if( ( l.sp1==0 && l.sp2==0 ) || fp==TRUE) S.h <- S.h1 <- S.h2 <- 0
@@ -251,7 +173,7 @@ if( ( l.sp1==0 && l.sp2==0 ) || fp==TRUE) S.h <- S.h1 <- S.h2 <- 0
     if(length(pPen2)!=0){ 
                           indP2 <- (qu.mag$off[l.sp1+1]-X1.d2):(-X1.d2+qu.mag$off[l.sp1+1]+qu.mag$rank[l.sp1+1]-1)
                           dimP2 <- length(indP2)
-                          ma2[indP2,indP2] <- S[indP2+X1.d2,indP2+X1.d2]
+                          ma2[indP2,indP2] <- S[(dimP1+1):(length(indP2)+dimP1),(dimP1+1):(length(indP2)+dimP1)]
                                 }                                 
     
     lP1 <- length(pPen1); lP2 <- length(pPen2) 
@@ -283,7 +205,7 @@ if( ( l.sp1==0 && l.sp2==0 ) || fp==TRUE) S.h <- S.h1 <- S.h2 <- 0
               dl.dbe1=dl.dbe1, dl.dbe2=dl.dbe2, dl.drho=dl.drho,
               d2l.be1.be1=d2l.be1.be1, d2l.be2.be2=d2l.be2.be2, 
               d2l.be1.be2=d2l.be1.be2, d2l.be1.rho=d2l.be1.rho,
-              d2l.be2.rho=d2l.be2.rho, d2l.rho.rho=d2l.rho.rho,good=good)     
+              d2l.be2.rho=d2l.be2.rho, d2l.rho.rho=d2l.rho.rho,good=good, PL=PL, eqPL=eqPL,BivD=BivD)     
 
 }
 
