@@ -10,7 +10,7 @@ if(object$RE==TRUE && object$RE.type=="N"){  Kk1 <- 0; k.n <- 1}
                                     ind <- fir:sec }
                                    
            ss.pred$coefficients <- object$coefficients[ind]
-           ss.pred$Vp <- object$Vb[ind,ind] # recall that with GEV this function is not good when predicting on the response scale
+           ss.pred$Vp <- object$Vb[ind,ind] # recall that with PL this function is not good when predicting on the response scale
 
   predict.gam(ss.pred, ...)
 
